from easypls import *
from typing import List

def gen_truth_table(vars: List[str], prop: str):
    engine = Engine()
    expr = Expr.parse(prop)

    def helper(i: int):
        if i >= len(vars):
            for var in vars:
                print(f"{var}={engine.eval(Expr.Var(var))}, ", end="")
            print(engine.eval(expr))
        else:
            engine.define(vars[i], True)
            helper(i+1)
            engine.define(vars[i], False)
            helper(i+1)

    print(prop + ":")
    helper(0)

gen_truth_table(["a", "b"], "a -> b")



from easypls import *

premises = [Expr.parse(s) for s in [
    "A -> (B and C)",
    "B -> (D or E)",
    "C -> F",
    "D -> G",
    "E -> G",
    "F -> H",
    "(G and H) -> I",
    "A",
]]

conclusion = Expr.Var("I")
valid = is_valid_argument(premises, conclusion)
print(f"Is argument 1 valid? {"yes" if valid else "no"}")

premises = [Expr.parse(s) for s in [
    "A -> (B and C)",
    "B -> D",
    "C -> E",
    "D or E",
    "F -> G",
    "G -> H",
    "A",
]]

conclusion = Expr.Var("H")
valid = is_valid_argument(premises, conclusion)
print(f"Is argument 2 valid? {"yes" if valid else "no"}")
